/***[f*****************************************************************
 *	PDataInt.h	-- Private Data Interface. 
 *
 *	Copyright 1996 (c) Adobe Systems, Inc. All Rights Reserved
 *
 *	Public version
 *	
 * $Revision:   1.5  $
 *
 * $Author:   MichaelMartz  $
 * $Date:   16 Jan 1997 13:01:00  $
 * $Log:   PMBUILDS:CM:BASELINE:pmsdk:includes:vcs:cipdata.hv  $
 * 
 *    Rev 1.5   16 Jan 1997 13:01:00   MichaelMartz
 * #188608: Organized member functions so that overload functions are co-located
 * 
 *    Rev 1.4   10 Sep 1996 09:57:46   edmundl
 * Removed SelectPub.
 * 
 *    Rev 1.3   27 Aug 1996 15:05:38   pnorton
 * fixed types, added vcs comments
 *
 ***f]*****************************************************************/

#ifndef __PDATAINT_H
#define __PDATAINT_H

#include "PMTypes.h"
#include "CIObjectAccess.h"

//	Some common data types
//
#define WINMETAFILE	"EMF"
#define MACPICT		"PICT"
#define POSTSCRIPT	"PS"

//	Seek type
//
typedef enum { PDSEEK_SET, PDSEEK_CUR, PDSEEK_END } SeekType;

class CIPrivateData : public CIInterface
{
public:
	virtual PMErr OpenPrivateData(char *pName, char *dataType, 
								unsigned long mustExist) = 0;
	virtual PMErr OpenPrivateData(PMOBJ_REC* pObjRec, char *dataType, 
								unsigned long mustExist) = 0;

	virtual PMErr ClosePrivateData() = 0;

 	virtual PMErr DeletePrivateData(char *pName, char *dataType) = 0;
	virtual PMErr DeletePrivateData(PMOBJ_REC* pObjRec, char *dataType) = 0;

	virtual PMErr DeletePrivateDataStorage(char *pName) = 0;
	virtual PMErr DeletePrivateDataStorage(PMOBJ_REC* pObjRec) = 0;
	
//	I/O functions
	virtual PMErr ReadPrivateData(void **pData, unsigned long size, unsigned long &aSize) = 0;
	virtual PMErr WritePrivateData(void *pData, unsigned long size) = 0;
	virtual PMErr SeekPrivateData(long offset, SeekType sType) = 0;

	virtual void FreeMemory(void *lpData) = 0;
};
  
#endif
