/***[f*****************************************************************
 *      ciwin.h -- Component Interface for PageMaker Windows.
 *
 *      Copyright 1996 (c) Adobe Systems, Inc. All Rights Reserved
 *
 *      Public version
 *
 * $Revision:   1.8  $
 *
 * $Author:   edmundl  $
 * $Date:   01 Oct 1996 11:57:22  $
 * $Log:   O:/baseline/pmsdk/includes/vcs/ciwin.hv  $
 * 
 *    Rev 1.8   01 Oct 1996 11:57:22   edmundl
 * Changed default parameter for AddToMenu.
 * 
 *    Rev 1.7   27 Sep 1996 11:25:30   edmundl
 * #152975: Implemented menu enabling for plugin palettes in story editor 
 * , layout and no pub state.
 * 
 *    Rev 1.6   29 Aug 1996 19:13:26   PMBuilder
 * Updated to fix minor infractions
 * 
 *    Rev 1.5   28 Aug 1996 11:36:30   PMBuilder
 * Changed occurances of 'bool' to 'BOOL' to get clean compile.
 * 
 *    Rev 1.4   28 Aug 1996 10:41:28   PMBuilder
 * Changed bool back to BOOL for CIPMWindow methods for clean compile.
 * 
 *    Rev 1.3   27 Aug 1996 15:10:40   pnorton
 * fixed types, added vcs comments.
 * 
 ***f]*****************************************************************/

#ifndef __CIWIN_H
#define __CIWIN_H

#include "PMTypes.h"

#if defined(MACINTOSH)
typedef BOOL (*MACPROC)(EventRecord *);
#endif
#ifdef __cplusplus
// menu states for AddToMenu
#define kAdnLayoutState		0x0004		// enable in layout mode
#define kAdnStoryEditState	0x0008		// enable in story editor
#define kAdnNoPubState		0x0010		// enable in no pub state

// class to define PageMaker window style
class CIPMWinStyle : public CIInterface
{
public:
	virtual void SetBorderState(BOOL bBorder)=0;
	virtual void SetVisibilityState(BOOL bIsVisible)=0;
	virtual void SetTitleBarState(BOOL bHasTitleBar)=0;
	virtual void SetParentState(BOOL bIsParent)=0;
	virtual void SetChildState(BOOL bIsChild)=0;
	virtual void SetZoomState(BOOL bHasZoomBox)=0;
	virtual void SetSizeState(BOOL bIsSizeable)=0;
	virtual void SetCloseState(BOOL bHasCloseBox)=0;
	virtual void SetMaximizeState(BOOL bIsMaximized)=0;
	virtual void SetStayOnTopState(BOOL bIsStayOnTop)=0;
	virtual void SetModalState(BOOL bIsModal)=0;
	virtual void SetDefaultWindowState(BOOL bIsDefaultWindow)=0;
};

// class to create and destroy PageMaker window
class CIPMWindow : public CIInterface
{
public:
	virtual BOOL Create(CIPMWinStyle *pPlugInWinStyle, void *thePrivateWinData)=0;
	virtual BOOL Destroy()=0;
	virtual void SetPrivateWinData(void *thePrivateWinData)=0;
	virtual void *GetPrivateWinData()=0;
	virtual void SetTitle(char *title)=0;
#if defined (WINDOWS)
	virtual HWND GetWindowHandle()=0;
	virtual void GetSizeLimit(RECT *rect)=0;
	virtual void SetSizeLimit(RECT rect)=0;
#endif
#if defined(MACINTOSH)
	virtual GrafPtr GetWindowHandle()=0;
	virtual void GetSizeLimit(Rect *rect)=0;
	virtual void SetSizeLimit(Rect rect)=0;
#endif
	// menuState is kAdnLayoutState, kAdnStoryEditState, kAdnNoPubState
	virtual PMErr AddToMenu(char *pShowMenuString, char *pHideMenuString,
			WORD menuState=kAdnLayoutState|kAdnNoPubState)=0;
	virtual PMErr DeleteFromMenu(char *pShowMenuString, char *pHideMenuString)=0;
	virtual void Show()=0;
	virtual void Hide()=0;
	virtual BOOL IsVisible()=0;
};

#endif
#endif
