/*
 *--- PageMakerCQErrs.h --------------------------------------------------
 * Copyright (c) 1995, Adobe Systems, Inc.  All rights reserved.
 *
 * For PageMaker plug-ins, these are the most common category of errors.
 *
 * $Revision:   1.4  $
 *
 * $Author:   pnorton  $
 * $Date:   27 Aug 1996 15:14:14  $
 * $Log:   U:/pmsdk/includes/vcs/pmcqerrs.hv  $
 * 
 *    Rev 1.4   27 Aug 1996 15:14:14   pnorton
 * added vcs comments
 *
 *------------------------------------------------------------------------
 */
#ifndef __PageMakerCQErrs__
#define __PageMakerCQErrs__

#include "PMErrors.h"

enum
{
	CQ_NO_ERR                               = 0,
	CQ_SUCCESS                              = 0,
	CQ_IGNORED                              = 0,
//      SUCCESS                                 = 0,

	CQ_OPERATION_COMPLETE,                                  // for occaisions that completion requires a non-zero value.
											// This cannot be used as an error code.
	CQ_DONT_DISCARD                 = CQ_OPERATION_COMPLETE,        // tell PM not to free the plug-in yet

	// These are internal errors that should never be displayed.
	CQ_CTOR_INVALID_ARGS    = CQ_ER_BASE+1, // 7201: Object constructor failed due to bad args.
	CQ_CTOR_FAILED,                                                 // 7202: General constructor failure.
	CQ_NEW_FAILED,                                                  // 7203: a new failed.
	CQ_BAD_OBJECT,                                                  // 7204: Attempt to use an invalid object.
	CQ_COERCION_FAILED,                                             // 7205: Type coercion failed.
	CQ_NOT_IMPLEMENTED,                                             // 7206: unction is not currently implemented.

		// These are exportable errors:
	CQ_BUFFSIZE_TOO_SMALL,                                  // 7207: buffer size is too small.
	CQ_NSF_MEMORY,                                                  // 7208: Insufficient Memory to proceed
	CQ_INVALID_ARGS,                                                // 7209: one or more invalid arguments. internal, no # in message.
	CQ_NOT_ENOUGH_ARGS,                                             // 7210: Not enough arguments supplied.
	CQ_BAD_ARG_PACKET,                                              // 7211:Improper binary argument packet.
	CQ_SYS_FAILED,                                                  // 7212:some system operation failed.
	CQ_FAILURE                      = CQ_SYS_FAILED,        // 7212:generalized failure code.
//      FAILURE                         = CQ_FAILURE,           // 7212: Now used by C&Q & new API
	CQ_DIDNT_HANDLE,                                                // 7213:operation was not performed.
	CQ_CANT_HANDLE,                                                 // 7214:operation not performed by this module.
	CQ_INVALID_STATE,                                               // 7215:operation invalid in current module state.
	CQ_RES_NOT_FOUND,                                               // 7216:resource not found
	CQ_CANT_LOAD_ADD,                                               // 7217:cannot load Addition library
	CQ_ADD_NOT_FOUND,                                               // 7218:Addition resource not found
	CQ_ADD_INIT_FAILED,                                             // 7219:Addition nitialization failed
	CQ_INVAL_INT_VER,                                               // 7220:Invalid interface version
	CQ_ADDRES_NOT_FOUND,                                    // 7221:Registration resource not found
	CQ_NO_ARGS,                                                             // 7222:No Arguments supplied.
	CQ_INVALID_CQ_ARG,                                              // 7223:invalid argument to command or query. takes arg # in message.
	CQ_ADDN_ERR,                                                    // 7224:Error returned from the Addition.
	CQ_ADDN_CANT_ERR,                                               // 7225:Error from the Addition with "Cant" string.
	CQ_PARS_BAD_CMD,                                                // 7226:Parser can't regognize command
	CQ_PARS_BAD_ARG,                                                // 7227:Parser can't parse argument list
	CQ_OLD_CMD,                                                             // 7228:Command is no longer supported
	CQ_INVALID_OBJECTID,                                    // 7229:Object id. doesn't exist in pub (or on current page(s)) 
	CQ_LO_INVALID_MODE,                                             // 7230:Command or query works only in story editor.
	CQ_SE_INVALID_MODE,                                             // 7231:Command or query works only in layout view.
	CQ_SEARCH_STATUS,                                               // 7232:No match found, or search complete.
	CQ_CHANGEALL_STATUS,                                    // 7233:No matches found. Search complete.
	CQ_SPELL_STATUS,                                                // 7234:No spelling errors detected, or spelling check complete.
	CQ_NOPDATA,                                                             // 7235:No private data found
	CQ_INVALID_TARGET,                                              // 7236:Specified target does not exist
	CQ_PDATA_ALREADY_EXISTS,                                // 7237:Private data already exists for specified target
	CQ_INVALID_CLASS,                                               // 7238:Invalid target class
	CQ_STRING_TOO_BIG,                                              // 7239:Private data string too big
	CQ_NO_INITIAL_SEARCH,                                   // 7240:Command must follow find or change command
	CQ_INITDICTERROR,                                               // 7241:Error initializing language dictionary
	CQ_DUPWORDDICTERROR,                                    // 7242:Word is already in user dictionary
	CQ_ADDTODICTERROR,                                              // 7243:Unable to add new word to user dictionary
	CQ_NOWORDDICTERROR,                                             // 7244:Word was not found in user dictionary
	CQ_ACCESSDICTERROR,                                             // 7245:Error accessing language dictionary
	CQ_OPENDICTERROR,                                               // 7246:Could not open user dictionary
	CQ_PDATA_OPEN,                                                  // 7247:A stream is already open
	CQ_ACCESS_DENIED,                                               // 7248:A specific stream is opened by another interface
	CQ_NO_PDATA_OPEN,                                               // 7249:No private data stream is opened
	CQ_SEEK_ERROR,                                                  // 7250:Seek error
	CQ_DISK_FULL,                                                   // 7251:Disk full
		// Insert new errors here:
	
	CQ_LAST_ERR                                                             // Last CQ Error.
};

enum CQLocation 
{
	CQ_XADN = CQ_AC_BASE+1,                                 //  Errors from the Addition XComponent.
	CQ_XAE,                                                                 //  Errors from the Apple IAC XComponent.
	CQ_XDDE,                                                                //  Errors from the DDE XComponent.
	CQ_XPRS,                                                                //  Errors from the XParser class.
	CQ_XIPS,                                                                //  Errors from the Internal XParser.
	CQ_XDTA,                                                                //  Errors from the XPMData object.
	CQ_QWRY,                                                                //  Errors from the Query Services.
	CQ_CMND,                                                                //  Errors from the Command Services.
	CQ_XMEM,                                                                //      Errors from the XMemory object.
	CQ_ADDREG                                                               //      Errors in registering Addition.
};


#endif

// end of PageMakerCQErrs.h


