/**[f******************************************************************
 *	PMEvtRec.h -- PageMaker Event Records
 *
 *	Copyright (c) 1996 Adobe Systems, Inc. All Rights Reserved
 *
 *	
 * ABSTRACT:  
 * 		This file contains record definitions for various PM events.
 *
 * USAGE: 
 *
 * ROUTINES DEFINED:
 *
 * $Revision:   1.6  $
 *
 * $Author:   NaokiH  $ 
 * $Date:   12 Sep 1996 14:10:28  $   
 *
 * $Log:   PMBuilds:CM:BASELINE:pmsdk:includes:vcs:pmevtrec.hv  $ 
 * 
 *    Rev 1.6   12 Sep 1996 14:10:28   NaokiH
 * Added a record for hyperlink click.
 * 
 *    Rev 1.5   27 Aug 1996 15:15:08   pnorton
 * fixed types, added vcs comments.
 * 
 *    Rev 1.4   01 Aug 1996 14:29:28   edmundl
 * added filename.
 * 
 *    Rev 1.3   22 Jul 1996 16:14:16   JGarner
 * Added PMEVT_OBJEDIT_MEDIA_IMAGE.
 * 
 *    Rev 1.2   03 Jul 1996 15:03:30   edmundl
 * Extensibility work.
 * 
 *    Rev 1.1   02 Jul 1996 16:12:42   tommyd
 * Removed typedef of PMOBJ_REC from here and instead get it by #include
 * ciobjacc.h.
 * 
 *    Rev 1.0   14 Jun 1996 14:42:46   edmundl
 * Initial revision.
 * 
 *    Rev 1.2   10 Jun 1996 18:34:00   tommyd
 * Added PMOBJ_REC.
 * 
 *    Rev 1.1   10 Jun 1996 10:40:28   hchan
 * event notification records.
 * 
 *    Rev 1.0   07 Jun 1996 15:47:18   hchan
 * Initial revision.
 * 
 *
 **f]******************************************************************/ 
#ifndef _PMEVTREC_H
#define _PMEVTREC_H

#include "CIObjectAccess.h"

// Plugin filespec
typedef struct _PMFILE_SPEC_REC {
	char			*pfileName;				// address of File name. 
#ifdef MACINTOSH 
	short			*vRefNum;           	// Volume or WD ref number 
	long			*dirID;
#endif // MACINTOSH
} PMFILESPEC, *PPMFILESPEC;

#ifndef RID
typedef unsigned long RID;
#endif
						
// Event Record for PMEVT_OPENPUB_BEFORE
typedef struct _PMOPENPUB_REC {
	PMFILESPEC	*pfSpec;		// address containing the pub's filespec
	unsigned short		openCopy;		// == 1 for Open Copy, == 0 for Open Original
} PMEVT_OPENPUB_REC, *PPMEVT_OPENPUB_REC;

// Event Record for PMEVT_INSERTPAGES_BEFORE
typedef struct _PMINSERTPAGES_REC {
	unsigned short		firstnewpage;	// Page number of page to add before 
	unsigned short		numpages;		// Number of pages to add
	RID					idleftmp;		// left master page index 
	RID					idrightmp;		// right master page index 
} PMEVT_INSERTPAGES_REC, *PPMEVT_INSERTPAGES_REC;

// Event Record for PMEVT_REMOVEPAGES_BEFORE
typedef struct _PMREMOVEPAGES_REC {
	unsigned short		firstremovedpage;	// Page number of page to remove 
	unsigned short		numremoved;			// Number of pages to remove
} PMEVT_REMOVEPAGES_REC, *PPMEVT_REMOVEPAGES_REC;

// Event Record for PMEVT_DELETEOBJECT_BEFORE 
typedef struct _PMDELETEOBJECT_REC {
	unsigned short			deleteState;	// =1 when first delete/redo delete, =2 for undodelete, =3 for CommitDelete
	PMOBJ_REC		objAccRec;		// object record for ObjectAccess interface
} PMEVT_DELETEOBJECT_REC, *PPMEVT_DELETEOBJECT_REC;

// Event Record for PMEVT_MULTIPLEPASTE_BEFORE
typedef struct _PMMULTIPLEPASTE {
	unsigned short	numMultiPastes;			// num times to repeat the paste
	long	pasteHorizOffset;		// X offset for each paste of object
	long	pasteVertOffset;		// Y offset for each paste of object
} PMEVT_MULTIPLEPASTE_REC, *PPMEVT_MULTIPLEPASTE_REC;

// Event Record for PMEVT_LAYOUT_DRAWOBJECT_BEFORE
typedef struct _PMLAYOUT_DRAWOBJECT_REC {
	unsigned short			bPrinting;		// =0 for display, =1 for print
	PMOBJ_REC		objAccRec;		// object record for ObjectAccess interface
} PMEVT_LAYOUT_DRAWOBJECT_REC, *PPMEVT_LAYOUT_DRAWOBJECT_REC;

// Event Record for PMEVT_EXPORT_BEFORE, PMEVT_PLACE_BEFORE, PMEVT_SAVEGRAPHIC_BEFORE
typedef struct _PMFILESPEC_REC {
	PMFILESPEC	*pfSpec;		// address containing the file's filespec
} PMEVT_FILESPEC_REC, *PPMEVT_FILESPEC_REC;

// Event Record for PMEVT_RELINK_AFER
typedef struct _PMRELINK_REC {
	PMFILESPEC	*pOldFSpec;		// address containing the old graphic's filespec
	PMFILESPEC	*pNewFSpec;		// address containing the new graphic's filespec
} PMEVT_RELINK_REC, *PPMEVT_RELINK_REC;

// Event Record for PMEVT_MENUCOMMAND_BEFORE
typedef struct _PMMENUCOMMAND {
	unsigned short		menuItemID;		// PageMaker menu item ID
	unsigned short		menuGroupID;	// PageMaker menu group ID
} PMEVT_MENUCOMMAND_REC, *PPMEVT_MENUCOMMAND_REC;

// Event Record for PMEVT_GOTOPAGE_BEFORE
typedef struct _PMGOTOPAGE_REC {
	unsigned short		newPage;		// page number to goto
	unsigned short		isaMasterPage;	// =1 if going to a master page, else =0
} PMEVT_GOTOPAGE_REC, *PPMEVT_GOTOPAGE_REC;

// Event Record for PMEVT_OBJECT_DBLCLICK_BEFORE
typedef struct _PM_OBJECT_DBLCLICK_REC {
	PMOBJ_REC	objAccRec;		// object record for ObjectAccess interface
} PMEVT_OBJECT_DBLCLICK_REC, *PPMEVT_OBJECT_DBLCLICK_REC;

// Event Record for PMEVT_PLUGIN_COMMAND_BEFORE & PMEVT_PLUGIN_COMMAND_AFTER
typedef struct _PMPLUGINCOMMAND {
	unsigned short		ComandID;		// Plugin Command ID
	long		retCode;		// Retcode for PMEVT_PLUGIN_COMMAND_AFTER only
	void *		ParamData;		// ParamData - need PMIBasic GetParm routines
} PMEVT_PLUGIN_COMMAND, *PPMEVT_PLUGIN_COMMAND; 

// Event Record for PMEVT_OBJEDIT_MEDIA_IMAGE
typedef struct
{
	PMOBJ_REC	objAccRec;
	char		mediaType[4];
	char		pluginType[4];
} PMEVT_OBJEDIT_MEDIA_IMAGE_REC, *PPMEVT_OBJEDIT_MEDIA_IMAGE_REC;

// Event Record for PMEVT_STYLE_AFTER
typedef struct _PMSTYLE_REC {
	unsigned short		bEditStyle;		// =1 for edit only, =0 apply to current selection/default
} PMEVT_STYLE_REC, *PPMEVT_STYLE_REC;

// Event Record for PMEVT_COLOR_AFTER
typedef struct _PMCOLOR_REC {
	unsigned short		bEditColor;		// =1 for edit only, =0 apply to current selection/default
} PMEVT_COLOR_REC, *PPMEVT_COLOR_REC;

// Event Record for PMEVT_HLINK_CLICK_REC
typedef struct _PMEVT_HLINK_CLICK_REC {
	unsigned long		hcmObjectId;	// hcm object id
} PMEVT_HLINK_CLICK_REC, *PPMEVT_HLINK_CLICK_REC;

#endif	// _PMEVTREC_H
