/**************************
 *      PMMenuID.h -- Header file for PageMaker Menu ID's 
 *
 *      Copyright (c) 1996 Adobe Systems, Inc. All Rights Reserved
 *
 *      
 * ABSTRACT: Header file for PageMaker Menu IDs. 
 *
 * USAGE: PMEVT_MENUCOMMAND_BEFORE Event Record contains 
 *		unsigned short		menuItemID;		// PageMaker menu item ID
 *		unsigned short		menuGroupID;	// PageMaker menu group ID
 *		
 *		where
 *				menuGroupID is the main menu or hierarchical menu ID and 
 *				menuItemID is selected menu item under menuGroupID
 *
 *
 *
 *********************************************************************/   
#ifndef _PMMENUID_H
#define _PMMENUID_H

#define SYSMENU								0x0100
#define FILEMENU							0x0200
#define EDITMENU							0x0300
#define LAYOUTMENU							0x0400
#define TYPEMENU							0x0500
#define ELEMENTMENU							0x0600
#define UTILITIESMENU						0x0700
#define WINMENU								0x0800
#define VIEWMENU							0x0900

//	The only menu that is different for the Story Editor
//	is the story menu.  The rest of the menus are shared.
#define STORYMENU							0x0B00

#ifdef WINDOWS
	#define HELPMENU						0x0C00
#else
	#define HELPMENU						0x2580
#endif

/***************************** Menu IDs for hierarchicals ************************************************/

#define FACEMENU							0x1500 
#define SIZEMENU							0x1600 
#define LEADMENU							0x1700 
#define FORMATMENU							0x1800 
#define JUSTIFYMENU							0x1B00 
#define STYLEMENU							0x1C00 
#define WIDTHMENU 							0x1E00 
#define TRACKMENU							0x1F00 
#define LINESMENU							0x2000 
#define SHADESMENU							0x2100 
#define ADDITIONSMENU						0x3C00 
#define OLEOBJECTMENU						0x3D00 
#define ZOOMMENU							0x3F00 
#define ARRANGEMENU							0x4000 

#define PRINTERSTYLESMENU					0x4300  
#define QUICKMENU							0x4400 
#define ACQUIREMENU							0x4500  
#define IMAGEMENU							0x4600 

#ifdef MACINTOSH
	#define POSMENU							0x1900 
	#define CASEMENU						0x1A00 
	#define COLORMENU						0x1D00 	 
	#define EDITIONSMENU					0x3B00 
	#define COLORLIBSMENU					0x3E00 
	#define LSTYLESMENU						0x4100 
#endif	/* MACINTOSH */

#define DELETELAYERMENU						0x4E00	 
#define LAYERCOLORMENU						0x4F00 
#define	PALETTEMENU							0x5200 
#define EXPORTMENU							0x5300 
#define PREFMENU							0x5400 
#define FRAMEMENU							0x5500 
#define FRAMEVALIGNPOPUP					0x5600 
#define FRAMEHALIGNPOPUP					0x5700 

/*********************************** Actual Menu item number ****************************************
 *
 * The following menu item constants tell you exactly which menu item was hit. M_BLAH is a combination of which menu
 *	was hit and the offset into that particular menu. For example, M_PLACE is defined as (FILEMENU + 10). That means that
 *	it's the 10th item in the file menu. 
 ***********************************************************************************************************************/

/********************************************* System menu items *******************************************************/


#define	M_CLIPBOARD						(SYSMENU + 6)

#ifdef WINDOWS
#define	M_HELP_CONTENTS					(SYSMENU + 2)
#define M_HELP_SHORTCUTS				(SYSMENU + 8)	//	"Shortcuts..." for help
#endif	//	WINDOWS


#ifdef MACINTOSH
#define M_HELP_CONTENTS					(HELPMENU + 1)
#define M_HELP_SHORTCUTS				(HELPMENU +  2)	//	"Topics..." for help
#define Q_HELP_SHORTCUTS				(SYSMENU + 8)	//	"Shortcuts..." for help
#endif

/**********************************************	File menu items *********************************************************/

#define M_NEW							(FILEMENU +  1)
#define M_OPEN							(FILEMENU +  2)
#define M_QUICK_OPEN					(FILEMENU +  3)
//	.......................................... +  4
#define M_CLOSE							(FILEMENU +  5)
#define M_SAVE							(FILEMENU +  6)
#define M_SAVE_AS						(FILEMENU +  7)
#define M_REVERT						(FILEMENU + 8)
//	.......................................... +  9
#define M_PLACE							(FILEMENU + 10)
//	.......................................... +  11
#define M_ACQUIRE						(FILEMENU + 12)
#define M_EXPORT						(FILEMENU + 13)
//	.......................................... + 14
#define M_LINKS							(FILEMENU + 15)
//	.......................................... + 16
#define M_PAGE_SETUP					(FILEMENU + 17)
#define M_PRINTER_STYLES				(FILEMENU + 18)
#define M_PRINT							(FILEMENU + 19)
//	.......................................... + 20
#define M_PREFERENCES					(FILEMENU + 21)
//	.......................................... + 22
#define M_QUIT							(FILEMENU + 23)


//
#ifdef WINDOWS
#define M_SEND_MAIL						(FILEMENU + 25)
#endif	//	WINDOWS

/*********************************************	Edit menu items **********************************************************/

#define M_UNDO							(EDITMENU +  1)
//	.......................................... +  2
#define M_CUT							(EDITMENU +  3)
#define M_COPY							(EDITMENU +  4)
#define M_PASTE							(EDITMENU +  5)
#define M_CLEAR							(EDITMENU +  6)
//	.......................................... +  7
#define M_SELECT_ALL					(EDITMENU +  8)
#define M_SELECT_NONE					(EDITMENU +  9)
//	.......................................... +  10
/******** Mac specific items on Edit menu*/
#ifdef MACINTOSH
	#define M_EDITIONS					(EDITMENU + 11)
//	.......................................... + 12
	#define M_MULTIPASTE				(EDITMENU + 13)
	#define M_PASTE_SPECIAL				(EDITMENU + 14)
	#define M_INSERT_OBJECT				(EDITMENU + 15)
//	.......................................... + 16
	#define M_EDIT_STORY				(EDITMENU + 17)
	#define M_EDIT_ORIGINAL				(EDITMENU + 18)
//	.......................................... + 19
	#define M_SHOW_CLIPBOARD			(EDITMENU + 20)
#endif  // MACINTOSH

/***** Windows specific items on Edit menu **/
#ifdef WINDOWS
	#define M_MULTIPASTE				(EDITMENU + 11)
	#define M_PASTE_SPECIAL				(EDITMENU + 12)
	#define M_INSERT_OBJECT				(EDITMENU + 13)
//	.......................................... + 14
	#define M_EDIT_STORY				(EDITMENU + 15)
	#define M_EDIT_ORIGINAL				(EDITMENU + 16)
#endif // WINDOWS

//	Used when an OLE object is selected, to replace the Edit Original menu.
#if defined( WINDOWS )
	#define M_OLE_OBJECT				(EDITMENU + 30)
#endif /* WINDOWS */

#if defined(WINDOWS)
	/* Used when an OLE object is selected, to replace the Edit Original menu. */
	#define M_OLE_OBJECT_MIN			(EDITMENU + 100)
	#define M_OLE_OBJECT_MAX			(EDITMENU + 200)
#endif


//	used for paste and power paste shortcuts, must have a seperate id for the paste
//	invoked from a shortcut so we can pick up the Ctrl modifier on a menu hit
#define M_SC_PASTE						(EDITMENU + 31)
#define M_POWERPASTE					(EDITMENU + 32)
// Used for Select Active Layer and Select Extend Active Layer.
// This lives in the layers palette menu, but still has a keyboard shortcut.
#define M_SELECTACTIVELAYER				(EDITMENU + 33)
#define M_SELECTEXTENDACTIVELAYER		(EDITMENU + 34)



/*****************************************	Layout menu items **************************************************************/

#define M_GOTOPAGE						(LAYOUTMENU +  1)
#define M_INSERT_PAGE					(LAYOUTMENU +  2)
#define M_REMOVE_PAGE					(LAYOUTMENU +  3)
#define M_SORT_PAGES					(LAYOUTMENU +  4)
//	............................................ + 5
#define M_GO_BACK						(LAYOUTMENU + 6)
#define M_GO_FORWARD					(LAYOUTMENU + 7)
//	............................................ +  8
#define M_COLUMN_GUIDES					(LAYOUTMENU +  9)
#define M_COPY_MASTER_GUIDES			(LAYOUTMENU + 10)
//	............................................ +  11
#define M_AUTO_FLOW						(LAYOUTMENU + 12)


//	Short cuts/modified commands  (not really menu items).
#ifdef MACINTOSH
#define M_NEXTPAGE						(LAYOUTMENU + 18)
#define M_PREVPAGE						(LAYOUTMENU + 19)
#define M_INSERT_ONE_PAGE				(LAYOUTMENU + 20)
#endif	//	MACINTOSH

//	Since the keyboard shortcut table is RCDATA for Windows, can't do math
//	in the defines, must update these if the typemenu id changes
#ifdef WINDOWS
#define M_NEXTPAGE		0x0412	//	(LAYOUTMENU + 18)
#define M_PREVPAGE		0x0413	//	(LAYOUTMENU + 19)
#define M_INSERT_ONE_PAGE	0x414	//	(LAYOUTMENU + 20)
#endif	//	WINDOWS


/*********************************************** Type menu items **************************************************************/

/* The following are defined explicitly because they are used in RCDATA statements on the PC, which don't like addition */
#define M_FONT				0x0501	//	(TYPEMENU +  1)
#define M_SIZE 				0x0502	//	(TYPEMENU +  2)
#define M_LEADING			0x0503	//	(TYPEMENU +  3)
#define M_TYPE_STYLE		0x0504	//	(TYPEMENU +  4)
//	.......................................... +  5
#define M_EXPERT_KERN					(TYPEMENU +  6)
#define M_TRACK				0x0507	//	(TYPEMENU +  7)
#define M_SET_WIDTH			0x0508	//	(TYPEMENU +  8)
//	.......................................... +  9
#define M_TYPE_SPECS					(TYPEMENU + 10)
#define M_PARA_SPECS					(TYPEMENU + 11)
#define M_TABS							(TYPEMENU + 12)
#define M_HYPHEN_SPECS					(TYPEMENU + 13)
//	.......................................... + 14
#define M_ALIGNMENT			0x050F	//	(TYPEMENU + 15)
#define M_STYLES			0x0510	//	(TYPEMENU + 16)
//	.......................................... + 17
#define M_DEFINE_STYLE				(TYPEMENU + 18)

//	Shortcuts (not really menu items)
#ifdef MACINTOSH
#define M_UPNEXTSIZE					(TYPEMENU + 24)
#define M_DOWNNEXTSIZE					(TYPEMENU + 25)
#define M_UPONEPOINT					(TYPEMENU + 26)
#define M_DOWNONEPOINT					(TYPEMENU + 27)
#define M_KERN_CLOSER_FINE				(TYPEMENU + 28)
#define M_KERN_CLOSER_COARSE			(TYPEMENU + 29)
#define M_KERN_APART_FINE				(TYPEMENU + 30)
#define M_KERN_APART_COARSE				(TYPEMENU + 31)
#define M_CLEAR_KERN					(TYPEMENU + 32)
#define M_SWITCH_KEY_FOCUS				(TYPEMENU + 33)
#define M_TOGGLE_UNITS					(TYPEMENU + 34)
#define M_SWITCH_CTRLPAL_MODE			(TYPEMENU + 35)

#define M_INSERT_DUMB__SINGLE_QUOTE		(TYPEMENU + 36)
#define M_INSERT_DUMB__DOUBLE_QUOTE		(TYPEMENU + 37)

#endif	//	MACINTOSH

//	since the keyboard shortcut table is RCDATA for Windows, can't do math
//	in the defines, must update these if the typemenu id changes
#ifdef WINDOWS
#define M_UPNEXTSIZE				0x0518	//	(TYPEMENU + 24)
#define M_DOWNNEXTSIZE				0x0519	//	(TYPEMENU + 25)
#define M_UPONEPOINT				0x051A	//	(TYPEMENU + 26)
#define M_DOWNONEPOINT				0x051B	//	(TYPEMENU + 27)
#define M_KERN_CLOSER_FINE			0x051C	//	(TYPEMENU + 28)
#define M_KERN_CLOSER_COARSE		0x051D	//	(TYPEMENU + 29)
#define M_KERN_APART_FINE			0x051E	//	(TYPEMENU + 30)
#define M_KERN_APART_COARSE			0x051F	//	(TYPEMENU + 31)
#define M_CLEAR_KERN				0x0520	//	(TYPEMENU + 32)
#define M_SWITCH_KEY_FOCUS			0x0521	//	(TYPEMENU + 33)
#define M_SWITCH_CTRLPAL_MODE		0x0522	//	(TYPEMENU + 34)
#define M_CTRLPAL_TAB				0x0523	//	(TYPEMENU + 35)
#define M_CTRLPAL_BACKTAB			0x0524	//	(TYPEMENU + 36)

#define M_INSERT_DUMB__SINGLE_QUOTE	0x0525	//	(TYPEMENU + 36)
#define M_INSERT_DUMB__DOUBLE_QUOTE	0x0526	//	(TYPEMENU + 37)
#endif	//	WINDOWS


/************************************************ Element menu ******************************************************************/
#define M_FILLS							(ELEMENTMENU +  1)
#define M_LINES							(ELEMENTMENU +  2)
#define M_FILL_LINE						(ELEMENTMENU +  3)
//	............................................. +  4
#define M_FRAMES						(ELEMENTMENU +  5)
//	............................................. +  6
#define M_ARRANGE						(ELEMENTMENU +  7)
#define M_ALIGN_OBJECTS					(ELEMENTMENU +  8)
#define M_AUTO_WRAP						(ELEMENTMENU +  9)
//	............................................. +  10
#define M_GROUP							(ELEMENTMENU + 11)
#define M_UNGROUP						(ELEMENTMENU + 12)
#define M_ANCHOR						(ELEMENTMENU + 13)
#define M_RELEASE						(ELEMENTMENU + 14)
//	............................................. +  15
#define M_MASK							(ELEMENTMENU + 16)
#define M_UNMASK						(ELEMENTMENU + 17)
//	............................................. +  18
#define M_IMAGE_HIER					(ELEMENTMENU + 19)
//	............................................. + 20
#define M_POLYGON_DFLT					(ELEMENTMENU + 21)
#define M_ROUNDED_CORNERS				(ELEMENTMENU + 22)
//	............................................. +  23
#define M_UPDATE_LINK       			(ELEMENTMENU + 24)
#define M_LINK_OPTIONS      			(ELEMENTMENU + 25)
//	............................................. + 26
#define M_NONPRINT						(ELEMENTMENU + 27)
#define M_REMOVE_TRANSFORM				(ELEMENTMENU + 28)



/******************************************	Utilities menu items ***********************************************************/

#define M_ADDITIONS						(UTILITIESMENU +  1)
//	............................................... +  2
#define M_FIND							(UTILITIESMENU +  3)
#define M_FIND_NEXT						(UTILITIESMENU +  4)
#define M_CHANGE						(UTILITIESMENU +  5)
#define M_SPELLING						(UTILITIESMENU +  6)
//	............................................... +  7
#define M_BOOK							(UTILITIESMENU +  8)
#define M_INDEXENTRY					(UTILITIESMENU +  9)
#define M_SHOWINDEX						(UTILITIESMENU + 10)
#define M_CREATEINDEX					(UTILITIESMENU + 11)
#define M_CREATETOC						(UTILITIESMENU + 12)
//	............................................... +  13
#define M_DEFINE_COLORS					(UTILITIESMENU + 14)

/*	Keyboard shortcuts - not really menu items. */
#define M_AUTOINDEX						(UTILITIESMENU + 24)	/* Automatic index entry */	/* !!!HUH - haven't done anything with these */
#define M_AUTONAMEINDEX					(UTILITIESMENU + 25)	/* Automatic name index entry */


/************************************************ View menu ******************************************************************/
#define M_MASTER_ITEMS					(VIEWMENU +  1)
#define M_SHOW_NONPRINT					(VIEWMENU +  2)
//	............................................ + 3
#define M_ZOOM_IN						(VIEWMENU +  4)
#define M_ZOOM_OUT						(VIEWMENU +  5)
#define M_ACTUAL_SIZE					(VIEWMENU +  6)
#define M_FIT_IN_WINDOW					(VIEWMENU +  7)
#define M_FIT_PASTEBOARD				(VIEWMENU +  8)
//	.......................................... +  9
#define M_ZOOM_TO						(VIEWMENU + 10)
//	.......................................... + 11
#define M_RULERS						(VIEWMENU + 12)
#define M_SNAP_TO_RULERS				(VIEWMENU + 13)
#define M_RULER_ZERO_LOCK				(VIEWMENU + 14)
//	.......................................... + 15
#define M_GUIDES						(VIEWMENU + 16)
#define M_SNAP_TO_GUIDES				(VIEWMENU + 17)
#define M_GUIDE_LOCK					(VIEWMENU + 18)
#define M_CLEAR_ALL_GUIDES				(VIEWMENU + 19)
#define M_GUIDES_POSITION				(VIEWMENU + 20)
//	.......................................... + 21
#define M_SCROLL						(VIEWMENU + 22)



/************************************************** Windows menu ********************************************************/
#ifdef MACINTOSH
	#define M_TILE						(WINMENU +  1)
	#define M_CASCADE					(WINMENU +  2)
	//	........................................ +  3
	#define M_TOOLBOX					(WINMENU +  4)
	#define M_CONTROLPALETTE			(WINMENU +  5)
	//	........................................ +  6
	#define M_COLOR_PANEL				(WINMENU +  7)
	#define M_STYLES_PANEL				(WINMENU +  8)
	#define M_LAYER_PANEL				(WINMENU +  9)
	#define M_MASTERPAGES_PANEL			(WINMENU + 10)
	#define M_HYPERLINKS_PANEL			(WINMENU + 11)
	//	........................................ + 12
	#define	M_PALETTES					(WINMENU + 13)
	//	........................................ + 14

#else // WINDOWS
		//		M_MDI_ICONS (arrange) 		         +  1
	#define M_TILE						(WINMENU +  2)
	#define M_CASCADE					(WINMENU +  3)
	//	........................................ +  4
	#define M_TOOLBOX					(WINMENU +  5)
	#define M_CONTROLPALETTE			(WINMENU +  6)
	//	........................................ +  7
	#define M_COLOR_PANEL				(WINMENU +  8)
	#define M_STYLES_PANEL				(WINMENU +  9)
	//	........................................ + 10
	#define M_LAYER_PANEL				(WINMENU + 11)
	#define M_MASTERPAGES_PANEL			(WINMENU + 12)
	//	........................................ + 13
	#define M_HYPERLINKS_PANEL			(WINMENU + 14)
	//	........................................ + 15
	#define	M_PALETTES					(WINMENU + 16)
	//	........................................ + 17
#endif // PLATFORM

/*************************************************** Palette menu ***********************************************/
#define M_SCRIPTPALETTE			(PALETTEMENU +  1)
#define M_LIBRARYPALETTE		(PALETTEMENU +  2)
#define M_PLUGINPALETTE			(PALETTEMENU +  3)


#define M_LAST_PALETTE		M_PALETTES

/************************* New Layer and Layer Options dialogs *********************/
#define M_LAYERCOLORMENU_ITEM			(LAYERCOLORMENU + 1)

/*************************************************** Lines & shades menu items ***********************************************/
#define  M_LINE_CUSTOM     (LINESMENU + 1)
#define	M_LINE_NONE			(LINESMENU + 2)
#define	M_SHADE_NONE		(SHADESMENU + 1)

/* all entries are relative to the particular pulldown */
#define M_LINE_NUM_CUSTOM				1
#define M_LINE_NUM_STYLE				4
#define M_LINE_NUM_DASH					5
#define M_LINE_NUM_SOLID				9
#define M_LINE_NUM_COUNT				(M_LINE_NUM_CUSTOM+M_LINE_NUM_STYLE+M_LINE_NUM_SOLID+M_LINE_NUM_DASH)

#ifdef WINDOWS
#define M_LINE_SEPARATOR1				(LINESMENU + M_LINE_NUM_COUNT + 1)
#define M_TRANSPARENT_LINE				(M_LINE_SEPARATOR1+1)
#define M_REVERSE_LINE					(M_LINE_SEPARATOR1+2)
#define M_LINE_NUM_ENTRIES				M_LINE_NUM_COUNT+3
#endif	//	WINDOWS

#ifdef MACINTOSH
#define M_TRANSPARENT_LINE				(LINESMENU + M_LINE_NUM_COUNT + 1)
#define M_REVERSE_LINE					(M_TRANSPARENT_LINE+1)
#define M_LINE_NUM_ENTRIES				M_LINE_NUM_COUNT+2
#endif	//	MACINTOSH


#define M_SHADE_NUM_TINT				3
#define M_SHADE_SEPARATOR1				(M_SHADE_NUM_TINT+1)
#define M_SHADE_NUM_PATTERN			8
#define M_SHADE_NUM_ENTRIES			(M_SHADE_SEPARATOR1+M_SHADE_NUM_PATTERN)

#define M_LINESTYLE_NUM_ENTRIES 		8

/* All other line and shade items are computed from the style number.
 * LineItem = M_LINE_NONE + EdgeStyle;
 * ShadeItem = M_SHADE_NONE + FillStyle;
 * The actual style specifications shift like sand, so we do not imply 
 * what they really are by a constant name.
 */


/********************************************** Hierarchical menu items ******************************************************/
/**************************** Edit original menu *******************************/
#if defined(MACINTOSH)
	#define M_OLE_OBJECT			(OLEOBJECTMENU + 1)
#endif

/**************************** Printer styles menu *******************************/
#define M_DEFINE_PRINTERSTYLE	(PRINTERSTYLESMENU + 1)

/*********************** PageMaker Plug-ins menu *******************************/
#define M_ADDITION_NAME					(ADDITIONSMENU +  1)

/**************************** Zoom menu ****************************************/
#define M_25_PERCENT					(ZOOMMENU +  1)
#define M_50_PERCENT					(ZOOMMENU +  2)
#define M_75_PERCENT					(ZOOMMENU +  3)
#define M_100_PERCENT					(ZOOMMENU +  4)
#define M_200_PERCENT					(ZOOMMENU +  5)
#define M_400_PERCENT					(ZOOMMENU +  6)

//	Shortcuts (not really menu items)
#ifdef MACINTOSH
#define M_FORCE_REDRAW					(ZOOMMENU + 10)
#endif

#ifdef WINDOWS
#define M_FORCE_REDRAW					(ZOOMMENU + 10)
#endif

/**************************** Arrange menu *******************************/
#define M_BRING_TO_FRONT				(ARRANGEMENU +  1)
#define M_BRING_FORWARD					(ARRANGEMENU +  2)
#define M_SEND_BACKWARD					(ARRANGEMENU +  3)
#define M_SEND_TO_BACK					(ARRANGEMENU +  4)

/**************************** Frame menu *******************************/
#define M_FRAME_ATTACH					(FRAMEMENU +  1)
#define M_FRAME_OPTIONS					(FRAMEMENU +  2)
#define M_CHANGE_TO_FRAME				(FRAMEMENU +  3)
//	............................................ +  4
#define M_FRAME_NEXT					(FRAMEMENU +  5)
#define M_FRAME_PREV					(FRAMEMENU +  6)
//	........................................... +  7
#define M_FRAME_BREAK_LINKS				(FRAMEMENU + 8)
//	............................................ +  9
#define M_FRAME_DEL_CONTENT				(FRAMEMENU + 10)


/* For the export menu */
#define M_PDF							(EXPORTMENU +  1)
#define M_HTML							(EXPORTMENU +  2)
//	............................................ +  3
#define M_IMAGE_SAVEAS					(EXPORTMENU +  4)
#define M_TEXT							(EXPORTMENU +  5)

/* For the preferences menu */
#define M_GENERAL_PREFS					(PREFMENU + 1)
//	............................................ +  2
#define M_ONLINE_PREFS					(PREFMENU + 3)
#define M_LAYOUT_ADJUSTMENT_OPTIONS		(PREFMENU + 4)
#define M_TRAPPINGOPTIONS				(PREFMENU + 5)





/* for the face menu */
#define M_FACENAME						(FACEMENU +  1)

/* For the format menu */
#define M_PLAIN							(FORMATMENU +  1)
#define M_BOLD							(FORMATMENU +  2)
#define M_ITALIC						(FORMATMENU +  3)
#define M_UNDERLINE						(FORMATMENU +  4)
#define M_STRIKETHROUGH					(FORMATMENU +  5)
#define M_OUTLINE						(FORMATMENU +  6)
#define M_SHADOW						(FORMATMENU +  7)
#define M_REVERSETYPE					(FORMATMENU +  8)

/* For the alignment menu */
#define M_ALIGN_LEFT					(JUSTIFYMENU +  1)
#define M_ALIGN_CENTER					(JUSTIFYMENU +  2)
#define M_ALIGN_RIGHT					(JUSTIFYMENU +  3)
#define M_JUSTIFY						(JUSTIFYMENU +  4)
#define M_FORCE_JUSTIFY					(JUSTIFYMENU +  5)

/* For the Set width menu */
#define M_WIDTH_OTHER					(WIDTHMENU +  1)
#define M_WIDTH_70						(WIDTHMENU +  2)
#define M_WIDTH_80						(WIDTHMENU +  3)
#define M_WIDTH_90						(WIDTHMENU +  4)
#define M_WIDTH_100						(WIDTHMENU +  5)
#define M_WIDTH_110						(WIDTHMENU +  6)
#define M_WIDTH_120						(WIDTHMENU +  7)
#define M_WIDTH_130						(WIDTHMENU +  8)

/* For the leading menu. We need define only the
 * first one, as for all the others, we convert the
 * string to a number
 */
#define M_OTHER_LEADING					(LEADMENU +  1)
#define M_AUTO_LEADING					(LEADMENU +  2)

/* for size menu */
#define M_OTHER_SIZE					(SIZEMENU +  1)

/* For the style menu */
// even though the menu is gone off of the type menu, we still need this 
// for the menu off of the control palette.  
#define M_NOSTYLE						(STYLEMENU +  1)

/* For the color menu */
/*#define M_COLOR_PALETTE				(COLORMENU +  1)*/

/* For the alignment popup menu in Paragraph dialog */
/* all entries are relative to the popup */
#define M_POPUP_LEFT					1
#define M_POPUP_CENTER					2
#define M_POPUP_RIGHT					3
#define M_POPUP_JUSTIFY					4
#define M_POPUP_FJUSTIFY				5

/* For the setwidth popup menu in Typespec dialog */
#define M_POPUP_WIDTH_100				4

/* For the case menu */
#define M_NORMAL_CASE					(CASEMENU +  1)
#define M_ALL_CAPS						(CASEMENU +  2)
#define M_SMALL_CAPS					(CASEMENU +  3)

/* For the Track menu */
#define M_EDIT_TRACKS					(TRACKMENU +  1)
//	........................................... +  2
#define M_NO_TRACK						(TRACKMENU +  3)
#define M_VLOOSE_TRACK					(TRACKMENU +  4)
#define M_LOOSE_TRACK					(TRACKMENU +  5)
#define M_NORMAL_TRACK					(TRACKMENU +  6)
#define M_TIGHT_TRACK					(TRACKMENU +  7)
#define M_VTIGHT_TRACK					(TRACKMENU +  8)

/* For the position menu */
#define M_NORMAL_POSITION				(POSMENU +  1)
#define M_SUPERSCRIPT					(POSMENU +  2)
#define M_SUBSCRIPT						(POSMENU +  3)

/* For the line end popup */
#define M_BREAK							(LINEENDPOPUP +  1)
#define M_NO_BREAK						(LINEENDPOPUP +  2)

#ifdef MACINTOSH
/* for the Editions menu */
#define	M_SUBSCRIBE_TO					(EDITIONSMENU +  1)
#define	M_SUBSCRIBE_OPT					(EDITIONSMENU +  2)
#define	M_STOP_EDITIONS					(EDITIONSMENU +  3)
#endif	//	MACINTOSH

#if	defined(CJK)
#define	M_RUBI					(EMBEDTEXTMENU + 1)
#define	M_VROMAN				(EMBEDTEXTMENU + 2)
#define	M_CAPTEXT				(EMBEDTEXTMENU + 3)
#define	M_SYNCHAR				(EMBEDTEXTMENU + 4)
//	.................................................. + 5
#define	M_CLEAR_RUBI			(EMBEDTEXTMENU + 6)
#define	M_REVERT_EMBED_TEXT		(EMBEDTEXTMENU + 7)
#endif

// for the color type popups in the edit colors dlog
#define M_CTYPE_SPOT				1
#define M_CTYPE_PROCESS				2
#define M_CTYPE_TINT1				3

#define M_CTYPE_HIFI				1
#define M_CTYPE_TINT2				2

// for the color model popups in the edit colors dlog
#define M_CMODEL_RGB				1
#define M_CMODEL_HSB				2
#define M_CMODEL_CMYK				3

#define M_CMODEL_NINK				1

#define M_PUBNAME						(QUICKMENU +  1)


#define M_IMAGE_SOURCE					(ACQUIREMENU +  1)
#define M_ACQUIRE_IMAGE					(ACQUIREMENU +  2)

#define M_IMAGE_INFO					(IMAGEMENU +  1)
#define M_CMS_SOURCE					(IMAGEMENU +  2)
#define M_PHOTOSHOP_EFFECTS				(IMAGEMENU +  3)

#ifdef DEBUG
//	Debug menu items.  The Mac numbers correspond to their position
//	in the menu; the Windows numbers can be anything.
#define M_GETRECORD						(DEBUGMENU +  1)   /* Both */
//	.............................................. +  2

#ifdef MACINTOSH

#define M_REPORTMEM						(DEBUGMENU +  3)
#define M_FLUSHMEM						(DEBUGMENU +  4)

#endif	//	MACINTOSH

//	.............................................. +  5
#define M_CALLTRACKING					(DEBUGMENU +  6) 
#define M_LOADTRACKING					(DEBUGMENU +  7)   
#define M_DISPLAYDEPTH					(DEBUGMENU +  8) 
//	.............................................. +  9
#define M_TRACKERDUMP					(DEBUGMENU + 10)
#define M_INCTRACKERLVL					(DEBUGMENU + 11)
#define M_TRACKERCLEAR					(DEBUGMENU + 12)

#endif  //	DEBUG

#ifdef MACINTOSH

#define M_SOURCEPROFILE					(PROFILEMENU + 1)
#define M_TRAPPROFILE					(PROFILEMENU + 2)
	
#endif // MACINTOSH


/********************************************* Story Editor Menu Items****************************************************/
//	All except the story menu are shared with Layout, so not done separately here.

//	Story Editor Story menu. See resource files for corresponding string names.
#define	M_S_NEW_STORY 					(STORYMENU +  1)
#define	M_S_CLOSE_STORY					(STORYMENU +  2)
//	................................................. +  3
#define	M_S_DISP_MARKS					(STORYMENU +  4)
#define	M_S_DISP_STYLES					(STORYMENU +  5)



#endif	_PMMENUID_H
