/*
 *--- ExportInterface.cpp ---------------------------------------------
 *  This sample plug-in adds a custom interface to PageMaker, which other 
 *		plug-ins can acquire through PageMaker.
 *
 *
 *
 * Copyright (c) 1997, Adobe Systems, Inc.  All rights reserved.
 * 
 *
 *------------------------------------------------------------------
 */

#include <string.h>

#include "PMPlugin.h"
#include "CIWindow.h"
#include "CICommandsAndQueries.h"
#include "CIInterfaceManager.h"
#include "PMInterfaceIDs.h"
#include "PMCQErrs.h"

#include "ExportInterface.h"
#include "PageInterface.h"

#include "PCL.h"

/*---externals ---*/
extern PMMessage			*gPMMessage;
extern sPMParamBlockPtr		gPB;
extern CIInterfaceManager	*gInterfaceMgr;
extern CICommandQuery		*gCmdQry;
extern PageInterface		*theInterface;
/*
 *--- ExportInterface ------------------------------------------------
 * No special initialization needed.
 *------------------------------------------------------------------
 */
ExportInterface::ExportInterface() : PPluginCall()
{

}

void ExportInterface::DoLoad()
{
// PageMaker will call this function each time your plug-in is loaded.
	gInterfaceMgr->AcquirePMInterface(PMIID_CMDQRY,  (void **)&gCmdQry);
	gCmdQry->Retrieve(&gPB);
	
}

void ExportInterface::DoInvoke()
{
// DoInvoke is called when your plug-in is launched from the 'Plug-ins' menu

}

void ExportInterface::DoUnload()
{
//When your plug-in is going to be unloaded, this function is called.
// PageMaker may load and unload your plug-in several times during a session if 
// the plug-in does not have the 'stay in memory' attribute set.
	gInterfaceMgr->ReleasePMInterface( gCmdQry );
	gCmdQry = NULL;
	gPB = NULL;

	if ( theInterface != NULL )
	{
		delete theInterface;
		theInterface = NULL;
	}

}

void ExportInterface::DoRegister()
{
// This is where you register your plug-in to receive event notification,
// DoRegister is also the first opportunity to add interfaces to PageMaker.
CIInterfaceManager *manager;

manager = sPMMessage->pInterfaceMgr;
manager->AddPMInterface(CIMyInterface);
}

void ExportInterface::DoEvent()
{
// This is where you handle the PageMaker events that you have requested
// notification for.

}

void ExportInterface::DoSysEvent()
{
// PageMaker will pass system events for windows that you create in your plug-in

}

void ExportInterface::DoAcquireInterface()
{
// If you've added an interface to PageMaker, then this function is called when
// another plug-in attempts to acquire the interface.
	PMInterface *acquiredIntf = ( PMInterface * )sPMMessage->pPMData;
	// If the interface that is being acquired is CIMyInterface, I'll pass back a pointer,
	// otherwise it's a failure.
	if (strcmp(acquiredIntf->pInterfaceName, CIMyInterface) == 0)
	{
		if (theInterface == NULL)
		{
			theInterface = new PageInterface();
		}
		acquiredIntf->pInterface = theInterface;
	}
	else
		throw CQ_FAILURE;
	
}

void ExportInterface::DoReleaseInterface()
{
// The interface that you have added to PageMaker has been released by another 
// plug-in. 
// This will be used when we do reference counting.

}


void ExportInterface::DoShutdown()
{
// The application is shutting down, and this is your last chance to clean things
// up, write preferences to disk, etc.
	
}
