/*
 *--- FramePlugin.cpp ---------------------------------------------
 *  Provides the framework for building new plug-ins
 *
 *
 *
 * Copyright (c) 1997, Adobe Systems, Inc.  All rights reserved.
 * 
 *
 *------------------------------------------------------------------
 */

#include <string.h>

#include "PMPlugin.h"
#include "CIWindow.h"
#include "CICommandsAndQueries.h"
#include "CIInterfaceManager.h"
#include "PMInterfaceIDs.h"
#include "PMCQErrs.h"

#include "ImportInterface.h"

#include "PCL.h"

#include "MyInterface.h"

/*---externals ---*/
extern PMMessage			*gPMMessage;
extern sPMParamBlockPtr		gPB;
extern CICommandQuery		*gCmdQry;
extern CIInterfaceManager	*gInterfaceMgr;

/*
 *--- ColorerPlugin ------------------------------------------------
 * No special initialization needed.
 *------------------------------------------------------------------
 */
ImportInterface::ImportInterface() : PPluginCall()
{

}

void ImportInterface::DoLoad()
{
// PageMaker will call this function each time your plug-in is loaded.
	gInterfaceMgr->AcquirePMInterface(PMIID_CMDQRY,  (void **)&gCmdQry);
	gCmdQry->Retrieve(&gPB);
}

void ImportInterface::DoInvoke()
{
// DoInvoke is called when your plug-in is launched from the 'Plug-ins' menu
MyInterface *borrowedInterface = NULL;
PMErr result;
short dummy;

	result = gInterfaceMgr->AcquirePMInterface((char *)CIMyInterface, (void **)&borrowedInterface);
	if ( result != CQ_SUCCESS )
	{
		throw result;
	}
	dummy = borrowedInterface->AddPage();
	gInterfaceMgr->ReleasePMInterface(CIMyInterface, (void **)borrowedInterface);
}

void ImportInterface::DoUnload()
{
//When your plug-in is going to be unloaded, this function is called.
// PageMaker may load and unload your plug-in several times during a session if 
// the plug-in does not have the 'stay in memory' attribute set.
	gInterfaceMgr->ReleasePMInterface( gCmdQry );
	gCmdQry = NULL;
	gPB = NULL;
}

void ImportInterface::DoRegister()
{
// This is where you register your plug-in to receive event notification,
// DoRegister is also the first opportunity to add interfaces to PageMaker.

}

void ImportInterface::DoEvent()
{
// This is where you handle the PageMaker events that you have requested
// notification for.

}

void ImportInterface::DoSysEvent()
{
// PageMaker will pass system events for windows that you create in your plug-in

}

void ImportInterface::DoAcquireInterface()
{
// If you've added an interface to PageMaker, then this function is called when
// another plug-in attempts to acquire the interface.

}

void ImportInterface::DoReleaseInterface()
{
// The interface that you have added to PageMaker has been released by another 
// plug-in. 

}


void ImportInterface::DoShutdown()
{
// The application is shutting down, and this is your last chance to clean things
// up, write preferences to disk, etc.
	
}
