/*
 *--- OpenCopy.cpp ---------------------------------------------
 * Demonstrates event notification & handling the 
 * PMEXT_MENUCOMMAND_BEFORE event.
 *
 *
 *
 * Copyright (c) 1997 Adobe Systems, Inc.  All rights reserved.
 * 
 *
 *------------------------------------------------------------------
 */

#include <string.h>

#include "PMPlugin.h"
#include "CIWindow.h"
#include "CICommandsAndQueries.h"
#include "CIInterfaceManager.h"
#include "PMInterfaceIDs.h"
#include "PMCQErrs.h"
#include "CIBasic.h"

#include "PMEvent.h"
#include "PMEventRec.h"
#include "PMMenuID.h"

#include "OpenCopy.h"

#include "PCL.h"

/*---externals ---*/
extern PMMessage			*gPMMessage;
extern sPMParamBlockPtr		gPB;
extern CIInterfaceManager	*gInterfaceMgr;
extern CICommandQuery		*gCmdQry;

extern void OpenPubCopy(void);
/*
 *--- OpenCopyPlugin ------------------------------------------------
 * No special initialization needed.
 *------------------------------------------------------------------
 */
OpenCopy::OpenCopy() : PPluginCall()
{

}

void OpenCopy::DoLoad()
{
// PageMaker will call this function each time your plug-in is loaded.
	gInterfaceMgr->AcquirePMInterface(PMIID_CMDQRY,  (void **)&gCmdQry);
	gCmdQry->Retrieve(&gPB);
}

void OpenCopy::DoInvoke()
{
// DoInvoke is called when your plug-in is launched from the 'Plug-ins' menu

}

void OpenCopy::DoUnload()
{
//When your plug-in is going to be unloaded, this function is called.
// PageMaker may load and unload your plug-in several times during a session if 
// the plug-in does not have the 'stay in memory' attribute set.
	gInterfaceMgr->ReleasePMInterface( gCmdQry );
	gPB = NULL;
	gCmdQry = NULL;
}

void OpenCopy::DoRegister()
{
// This is where you register your plug-in to receive event notification,
// DoRegister is also the first opportunity to add interfaces to PageMaker.

// The OpenCopy plug-in replaces the open dialog. To do this we need to catch
// the PMEVT_MENUCOMMAND_BEFORE event and handle the case that matches the 
// open dialog.
	
	PMErr 	result = CQ_SUCCESS;
	CIBasic	*basicPtr;
		
	// To register for events we need the RegisterPMEvent method in CIBasic.
	result = gInterfaceMgr->AcquirePMInterface( (unsigned long)PMIID_BASIC, (void **)&basicPtr );
	if ( result != CQ_SUCCESS )
	{
		throw result;	// we did not get the CIBasic interface
	}
	
	// Here we register for the event that will notify us any time the user
	//  selects a menu item in PageMaker.
	basicPtr->RegisterPMEvent(PMEVT_MENUCOMMAND_BEFORE);
	// Release the CIBasic interface
	gInterfaceMgr->ReleasePMInterface( basicPtr );

}

void OpenCopy::DoEvent()
{
// This is where you handle the PageMaker events that you have requested
// notification for.

PMErr	result = CQ_SUCCESS;
PMEvent	*event = (PMEvent *)sPMMessage->pPMData;
PPMEVT_MENUCOMMAND_REC menuItem;	//PPMEVT_MENUCOMMAND_REC is a pointer to a struct

if (event->eventID == PMEVT_MENUCOMMAND_BEFORE)
{
	menuItem = ( PPMEVT_MENUCOMMAND_REC )event->lParm;
	if ( ( menuItem->menuGroupID == FILEMENU ) && ( menuItem->menuItemID == M_OPEN ) )
	{
		OpenPubCopy();
		event->wasHandled = TRUE;				// Override the default dialog.
	}
}

}

void OpenCopy::DoSysEvent()
{
// PageMaker will pass system events for windows that you create in your plug-in

}

void OpenCopy::DoAcquireInterface()
{
// If you've added an interface to PageMaker, then this function is called when
// another plug-in attempts to acquire the interface.

}

void OpenCopy::DoReleaseInterface()
{
// The interface that you have added to PageMaker has been released by another 
// plug-in. 

}


void OpenCopy::DoShutdown()
{
// The application is shutting down, and this is your last chance to clean things
// up, write preferences to disk, etc.
	
}
