/*
 *--- Main.cp -------------------------------------------------
 * Copyright (c) 1997 Adobe Systems, Incorporated. All rights reserved.
 *
 * This file contains the main entry point for the plug-in
 *-------------------------------------------------------------
 */

#include "PMPlugin.h"

#ifdef MACINTOSH
#include <exception.h>
#else
#include <eh.h>
#endif //MACINTOSH

#if __MWERKS__ && __MC68K__
#include <A4Stuff.h>
#include <SetupA4.h>
#endif

#ifdef WINDOWS
#include <Windows.h>
#endif

#include "PDFNotes.h"		//PDFNotes is a subclass of PPluginCall


/* ---------------- PageMaker SDK include files ---------------- */
#include "CIInterfaceManager.h"
#include "PMEvent.h"

#include "PMEventRec.h"
#include "CIBasic.h"
#include "PMInterfaceIDs.h"
#include "CICommandsAndQueries.h"
#include "CIObjectAccess.h"

//--- Global variables ----------------------------------------
sPMParamBlockPtr	gPB = NULL;	// Stores the current executing param block
PMMessage *			gPMMessage = NULL;
CIInterfaceManager * gInterfaceMgr = NULL;
CICommandQuery *	gCmdQry = NULL;

#ifdef WINDOWS
	PMHandle	hDllInstance;
#endif //WINDOWS


//--- Forward declarations ------------------------------------
#ifdef powerc
	#pragma export on
#endif
PMXErr main(PMMessage *pMsg);
#ifdef powerc
	#pragma export off
#endif

#ifdef WINDOWS
	BOOL WINAPI DllMain(HINSTANCE hInstance, ULONG ul_reason, LPVOID lpvReserved);
#endif

void NiceUnexpected();

PMXErr main(PMMessage *pMsg)
{
#if __MWERKS__ && __MC68K__
	long oldA4 = SetCurrentA4();
	RememberA4();
#endif

	gInterfaceMgr = pMsg->pInterfaceMgr;
	
	gPMMessage = pMsg;
	
	PMErr rc = CQ_SUCCESS;
	
	set_unexpected(NiceUnexpected);

	try
	{
		PDFNotes theCall;
		theCall.Dispatch();		// dispatch the call to your plug-in object
		rc = CQ_SUCCESS;
	}
	catch (PMErr err)
	{
		rc = err;
	}
	catch (...)
	{
		rc = CQ_FAILURE;		// something weird goin' if we get here...
	}

	//PageMaker doesn't give an error message when a plug-in returns an error so 
	// the following if statment will call ErrorAlert if we are about to return an
	// error code.
	if ( rc != CQ_SUCCESS )
	{
		gInterfaceMgr->AcquirePMInterface( PMIID_CMDQRY, (void **)&gCmdQry );
		gCmdQry->Retrieve(&gPB);
		gCmdQry->ErrorAlert(rc, gPB);
		gInterfaceMgr->ReleasePMInterface( (void *)gCmdQry );
	}

#if __MWERKS__ && __MC68K__
	SetA4(oldA4);
#endif

	return rc;
}

/*
 *--- NiceUnexpected ------------------------------------------
 * The default unexpected() exception handler calls terminate.
 * This is not very friendly behavior for a plug-in, so this
 * handler just throws a CQ_FAILURE.
 *
 * Note that the routines in the PageMaker Class Library
 * should never throw an unexpected exception, so this is
 * mostly to safeguard against exception handling errors that
 * may be introduced in your code or other class libraries
 * you use in your plug-in.
 *-------------------------------------------------------------
 */
void NiceUnexpected()
{
	throw (PMErr)CQ_FAILURE;
}

// end of Main.cp

#ifdef WINDOWS
BOOL WINAPI DllMain(HINSTANCE hInstance, ULONG ul_reason, LPVOID lpvReserved)
{
    hDllInstance = hInstance;	    /* save the Instance in a global var */

	switch(ul_reason)
	{
		case DLL_PROCESS_ATTACH:
			break;
		case DLL_THREAD_ATTACH:
			break;
		case DLL_THREAD_DETACH:
			break;
		case DLL_PROCESS_DETACH:
			break;
	}
    return TRUE;
}
#endif //WINDOWS