/*
 *--- PDFNotes.cpp ---------------------------------------------
 *  Adds notes to PDF Export.
 *  This sample plug-in demonstrates using the HyperContent Manager,
 *		and adding pdfmarks to the applications PDF export
 *
 *
 *
 * Copyright (c) 1997, Adobe Systems Incorporated. All rights reserved.
 * 
 *
 *------------------------------------------------------------------
 */

#include <string.h>

#include "PMPlugin.h"
#include "CICommandsAndQueries.h"
#include "CIInterfaceManager.h"
#include "HCMPlugs.h"
#include "CIObjectAccess.h"
#include "PMInterfaceIDs.h"
#include "PMCQErrs.h"

#include "PDFNotes.h"

#include "PCL.h"

/*---externals ---*/
extern PMMessage			*gPMMessage;
extern sPMParamBlockPtr		gPB;
extern CIInterfaceManager	*gInterfaceMgr;
extern CICommandQuery		*gCmdQry;

/*
 *--- ColorerPlugin ------------------------------------------------
 * No special initialization needed.
 *------------------------------------------------------------------
 */
PDFNotes::PDFNotes() : PPluginCall()
{

}

void PDFNotes::DoLoad()
{
// PageMaker will call this function each time your plug-in is loaded.
//	On load, we acquire the CICommandQuery Interface, and get the 
//	Parameter block, this saves the overhead of loading it each time 
//	a command is used, and ensures that we have the Parameter block
//	if the plug-in exports interfaces.
	gInterfaceMgr->AcquirePMInterface(PMIID_CMDQRY,  (void **)&gCmdQry);
	gCmdQry->Retrieve(&gPB);
	
}

void PDFNotes::DoInvoke()
{
	CHcmPlugInRegistry*			theHCM;
	CHcmPlugInContentHandler*	theHCHandler;
	HcmErr						testErr;


// DoInvoke is called when your plug-in is launched from the 'Plug-ins' menu
	// Create a box, and color it yellow
	PDeselect();
	PBox noteBox( 2880, 2880, 5760, 5760 );
	PColor noteColor("Yellow");

	// Turn the box into a nonprinting frame 
	// Frames don't print anyway, but normally the content would.
	PToggleFrame();
	PGetObjectIDList noteID;

	PNonPrinting noteState( true );
		
	//Add place-holder text to the note.
	PNewStory noteStory( 4320, 4320 );
	PTextEnter defaultText("Sample note. Changing text doesn't work.");

	PTool switchTool(kPointerTool);
	PSelectID getFrame(noteID.nObjectID);

	// Using the Hypercontent manager: First, acquire the HCM through the interface manager:
	gInterfaceMgr->AcquirePMInterface(PMIID_HYPERCONTENTMANAGER, (void **)&theHCM);
	
	// Use the HCM to register our plug-in for a PDFMark content handler. The HcmCallerIdEnum
	//		can be created programmatically to avoid conflicts ( check for 
	//    kHcmContentTypeAlreadyRegistered to see if the value is registered.)
	testErr = theHCM->ContentTypeRegister(static_cast<HcmCallerIdEnum>('SMPL'), kHcmContentTypePdfMark, NULL, &theHCHandler);
	
	HcmObjectId			   theHcmObject;
	HcmObjectCreateDescRec notePDFMark;
	// clear notePDFMark before we use it.
	memset(&notePDFMark, 0, sizeof(notePDFMark));
	

	// This sets up the HcmObjectCreateDescRec for an object, if the content is to be inserted 
	//	into a story, the text needs to be selected, and the PageMakerRec members would be:
	//		m_SegmentType = 33
	//		m_OuterRid    = INVAL_RID
	//		m-InnerRid	  = INVAL_RID
	notePDFMark.m_KindOfObject = kHcmStorageOnly;
	notePDFMark.m_PageMakerRec.m_SegmentType = noteID.cTypeOfObject;
	notePDFMark.m_PageMakerRec.m_OuterRid = noteID.nObjectID;
	notePDFMark.m_PageMakerRec.m_InnerRid = INVAL_RID;
	notePDFMark.m_PrivateStore.m_StoreBuffer = "/Contents (Sample note) /ANN pdfmark";
	notePDFMark.m_PrivateStore.m_SizeOfBuffer = 36;

	// Anchors and hyperlink sources show up in the hyperlink palette, but storage only items
	// do not.
	testErr = theHCHandler->Create(&notePDFMark, &theHcmObject);


	// Since we haven't implemented 'editing the note' we're done with the handler and the HCM
	theHCM->ContentTypeUnregister(static_cast<HcmCallerIdEnum>('SMPL'), kHcmContentTypePdfMark);
	gInterfaceMgr->ReleasePMInterface(theHCM);


}

void PDFNotes::DoUnload()
{
//When your plug-in is going to be unloaded, this function is called.
// PageMaker may load and unload your plug-in several times during a session if 
// the plug-in does not have the 'stay in memory' attribute set.
	gInterfaceMgr->ReleasePMInterface( gCmdQry );
	gCmdQry = NULL;
	gPB = NULL;
}

void PDFNotes::DoRegister()
{
// This is where you register your plug-in to receive event notification,
// DoRegister is also the first opportunity to add interfaces to PageMaker.

}

void PDFNotes::DoEvent()
{
// This is where you handle the PageMaker events that you have requested
// notification for.

}

void PDFNotes::DoSysEvent()
{
// PageMaker will pass system events for windows that you create in your plug-in

}

void PDFNotes::DoAcquireInterface()
{
// If you've added an interface to PageMaker, then this function is called when
// another plug-in attempts to acquire the interface.

}

void PDFNotes::DoReleaseInterface()
{
// The interface that you have added to PageMaker has been released by another 
// plug-in. 

}


void PDFNotes::DoShutdown()
{
// The application is shutting down, and this is your last chance to clean things
// up, write preferences to disk, etc.
	
}
