/*
 *--- NewPalette.cpp ---------------------------------------------
 * Creates a new palette in PageMaker.
 *
 *
 *
 * Copyright (c) 1997, Adobe Systems, Inc.  All rights reserved.
 * 
 *
 *------------------------------------------------------------------
 */

#include <string.h>

#include "PMPlugin.h"
#include "CIWindow.h"
#include "CICommandsAndQueries.h"
#include "CIInterfaceManager.h"
#include "CIBasic.h"
#include "PMInterfaceIDs.h"
#include "PMCQErrs.h"
#include "PMEvent.h"

#include "NewPalette.h"

#include "PCL.h"

/*---externals ---*/
extern PMMessage			*gPMMessage;
extern sPMParamBlockPtr		gPB;
extern CIInterfaceManager	*gInterfaceMgr;
extern CICommandQuery		*gCmdQry;
extern short				ourResFile;
//extern NewPalette			*myPalette;

CIPMWindow					*thePalette = NULL;
CIPMWinStyle				*theAttribs = NULL;
#ifdef WINDOWS
extern HWND					hColorerPalette;
HWND						theWindowHandle;
#else // MACINTOSH
GrafPtr						theWindowHandle;
#endif


/*
 *--- ColorerPlugin ------------------------------------------------
 * No special initialization needed.
 *------------------------------------------------------------------
 */
NewPalette::NewPalette() : PPluginCall()
{

}

void NewPalette::DoLoad()
{
// PageMaker will call this function each time your plug-in is loaded.
//	On load, we acquire the CICommandQuery Interface, and get the 
//	Parameter block, this saves the overhead of loading it each time 
//	a command is used, and ensures that we have the Parameter block
//	if the plug-in exports interfaces.
	gInterfaceMgr->AcquirePMInterface(PMIID_CMDQRY,  (void **)&gCmdQry);
	gCmdQry->Retrieve(&gPB);
	
	
}

void NewPalette::DoInvoke()
{
// DoInvoke is called when your plug-in is launched from the 'Plug-ins' menu

}

void NewPalette::DoUnload()
{
//When your plug-in is going to be unloaded, this function is called.
// PageMaker may load and unload your plug-in several times during a session if 
// the plug-in does not have the 'stay in memory' attribute set.
	if( thePalette != NULL )
	{
		DestroyWindow(hColorerPalette);
		thePalette->DeleteFromMenu("Show Colorer Palette", "Hide Colorer Palette");
		thePalette->Destroy();
		gInterfaceMgr->ReleasePMInterface( thePalette );
		thePalette = NULL;
	}
	gInterfaceMgr->ReleasePMInterface( gCmdQry );
	gCmdQry = NULL;
	gPB = NULL;
	
//	delete myPalette;
//	myPalette = NULL;
}

void NewPalette::DoRegister()
{
// This is where you register your plug-in to receive event notification,
// DoRegister is also the first opportunity to add interfaces to PageMaker.
	CIBasic *basic = NULL;

// At registration time, the application is not fully initialized,
//	Since we will use commands and queries in creating the palette, we must
//	wait until the application has finished its startup routines, fortunately
//	we can register for the PMEVT_APP_STARTUP_AFTER event.
	gInterfaceMgr->AcquirePMInterface( (unsigned long)PMIID_BASIC, (void **)&basic );
	basic->RegisterPMEvent( (PMEventID) PMEVT_APP_STARTUP_AFTER );
	gInterfaceMgr->ReleasePMInterface( basic );


}

void NewPalette::DoEvent()
{
// This is where you handle the PageMaker events that you have requested
// notification for.
	PMEvent			*event;
	PMErr			errorCheck;
	CIPMWindow		*myWindow = NULL;
	CIPMWinStyle	*winAttribs = NULL;
	CIBasic			*basic = NULL;
	
	event = (PMEvent *) gPMMessage->pPMData;
	
	if ( event->eventID == PMEVT_APP_STARTUP_AFTER )
	{
		
		// First, acquire the CIPMWinStyle and CIPMWindow interfaces.	
		errorCheck = gInterfaceMgr->AcquirePMInterface( PMIID_WINSTYLE, (void **)&winAttribs );
		if ( errorCheck != CQ_SUCCESS )
		{
			throw errorCheck;
		}
		errorCheck = gInterfaceMgr->AcquirePMInterface( PMIID_WINDOW, (void **)&myWindow );
		if ( errorCheck != CQ_SUCCESS )
		{
			throw errorCheck;
		}
		
		// Our palette will be a fixed size, and set to 
		// stay on top. 
		winAttribs->SetBorderState(FALSE);
		winAttribs->SetVisibilityState(FALSE);
		winAttribs->SetTitleBarState(TRUE);
		winAttribs->SetZoomState(FALSE);
		winAttribs->SetSizeState(FALSE);
		winAttribs->SetCloseState(TRUE);
		winAttribs->SetMaximizeState(FALSE);
		winAttribs->SetStayOnTopState(TRUE);
		winAttribs->SetModalState(FALSE);
		winAttribs->SetDefaultWindowState(TRUE);
		
		// We will create the window, and leave it hidden.
		myWindow->Create(winAttribs, (void *)2);
		
		// We are done with the CIPMWinStyle interface and so we can
		//	release it now. We have to keep the pointer to the 
		//	CIPMWindow interface around as long as we are using the 
		//	palette.
		gInterfaceMgr->ReleasePMInterface(  winAttribs );

		myWindow->AddToMenu("Show Colorer Palette", "Hide Colorer Palette", 
				kAdnLayoutState | kAdnNoPubState | kAdnStoryEditState );
						
		theWindowHandle = myWindow->GetWindowHandle();
		

		thePalette = myWindow;

		gInterfaceMgr->AcquirePMInterface( (unsigned long)PMIID_BASIC, (void **)&basic);
		basic->UnregisterPMEvent( PMEVT_APP_STARTUP_AFTER );
		gInterfaceMgr->ReleasePMInterface( basic );
	}
//	InitMyPalette();


}

void NewPalette::DoSysEvent()
{
// PageMaker will pass system events for windows that you create in your plug-in
	PaletteEvents();
}

void NewPalette::DoAcquireInterface()
{
// If you've added an interface to PageMaker, then this function is called when
// another plug-in attempts to acquire the interface.

}

void NewPalette::DoReleaseInterface()
{
// The interface that you have added to PageMaker has been released by another 
// plug-in. 

}


void NewPalette::DoShutdown()
{
// The application is shutting down, and this is your last chance to clean things
// up, write preferences to disk, etc.

	
}
