/*
 *--- FramePlugin.cpp ---------------------------------------------
 *  Provides the framework for building new plug-ins
 *
 *
 *
 * Copyright (c) 1997, Adobe Systems, Inc.  All rights reserved.
 * 
 *
 *------------------------------------------------------------------
 */

#include <string.h>

#include "PMPlugin.h"
#include "CIWindow.h"
#include "CICommandsAndQueries.h"
#include "CIInterfaceManager.h"
#include "PMInterfaceIDs.h"
#include "PMCQErrs.h"

#include "FramePlugin.h"

#include "PCL.h"

/*---externals ---*/
extern PMMessage			*gPMMessage;
extern sPMParamBlockPtr		gPB;
extern CIInterfaceManager	*gInterfaceMgr;
extern CICommandQuery		*gCmdQry;

/*
 *--- ColorerPlugin ------------------------------------------------
 * No special initialization needed.
 *------------------------------------------------------------------
 */
FramePlugin::FramePlugin() : PPluginCall()
{

}

void FramePlugin::DoLoad()
{
// PageMaker will call this function each time your plug-in is loaded.
//	On load, we acquire the CICommandQuery Interface, and get the 
//	Parameter block, this saves the overhead of loading it each time 
//	a command is used, and ensures that we have the Parameter block
//	if the plug-in exports interfaces.
	gInterfaceMgr->AcquirePMInterface(PMIID_CMDQRY,  (void **)&gCmdQry);
	gCmdQry->Retrieve(&gPB);
	
}

void FramePlugin::DoInvoke()
{
// DoInvoke is called when your plug-in is launched from the 'Plug-ins' menu

}

void FramePlugin::DoUnload()
{
//When your plug-in is going to be unloaded, this function is called.
// PageMaker may load and unload your plug-in several times during a session if 
// the plug-in does not have the 'stay in memory' attribute set.
	gInterfaceMgr->ReleasePMInterface( gCmdQry );
	gCmdQry = NULL;
	gPB = NULL;
}

void FramePlugin::DoRegister()
{
// This is where you register your plug-in to receive event notification,
// DoRegister is also the first opportunity to add interfaces to PageMaker.

}

void FramePlugin::DoEvent()
{
// This is where you handle the PageMaker events that you have requested
// notification for.

}

void FramePlugin::DoSysEvent()
{
// PageMaker will pass system events for windows that you create in your plug-in

}

void FramePlugin::DoAcquireInterface()
{
// If you've added an interface to PageMaker, then this function is called when
// another plug-in attempts to acquire the interface.

}

void FramePlugin::DoReleaseInterface()
{
// The interface that you have added to PageMaker has been released by another 
// plug-in. 

}


void FramePlugin::DoShutdown()
{
// The application is shutting down, and this is your last chance to clean things
// up, write preferences to disk, etc.
	
}
